#ifndef _SuggestionMenu_h_
#define _SuggestionMenu_h_

// $Id: SuggestionMenu.h,v 1.8 2013/01/09 17:19:04 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "SpellInterface.h"

#include <QtGui/QMenu>
#include <QtCore/QHash>

namespace SPELLCHECK {

    //! customized popup menu to display spell checker suggestions
    class SuggestionMenu: public QMenu, public Counter
    {

        //! Qt meta object declaration
        Q_OBJECT

        public:

        //! constructor
        SuggestionMenu( QWidget *parent, const QString& word, const bool& = false );

        //! spell interface
        SpellInterface& interface( void )
        { return interface_; }

        signals:

        //! signal emited when a file is selected
        void suggestionSelected( QString );

        //! ignore word
        void ignoreWord( QString );

        private slots:

        //! load suggestions before showing the menu
        void _aboutToShow( void );

        //! select word from action
        void _select( QAction* );

        //! add word to dictionary
        void _addWord( void );

        //! ignore word
        void _ignoreWord( void )
        {
            if( word_.isEmpty() ) return;
            emit ignoreWord( word_ );
        }

        private:

        //! spell interface
        SpellInterface interface_;

        //! misspelled word
        QString word_;

        //! map actions to suggested words
        typedef QHash<QAction*, QString> SuggestionMap;
        SuggestionMap suggestions_;

    };
}

#endif
