// $Id: SeparatorPixmap.cpp,v 1.7 2012/12/20 10:07:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*******************************************************************************/

#include "SeparatorPixmap.h"

#include <QtGui/QImage>

//_________________________________________________________________
SeparatorPixmap::SeparatorPixmap(
    int width,
    int height,
    TaskBarAttributes::Layout layout ):
CustomPixmap()
{

    // default colors
    QRgb none( qRgba( 0, 0, 0, 0 ) );
    QRgb white( qRgba( 255, 255, 255, 64 ) );
    QRgb black( qRgba( 0, 0, 0, 64 ) );

    // create image
    QImage image( width, height, QImage::Format_ARGB32 );
    image.fill( none );

    if( layout & TaskBarAttributes::Horizontal )
    {

        Q_ASSERT( width >= 2 );
        int offset = (width - 2 )/2;
        for( unsigned int row = 0; row<height; row++ )
        {
            image.setPixel( offset, row, black );
            image.setPixel( offset+1, row, white );
        }

    } else if( layout & TaskBarAttributes::Vertical ) {

        Q_ASSERT( height >= 2 );
        int offset = (height - 2 )/2;
        for( unsigned int col = 0; col<width; col++ )
        {
            image.setPixel( col, offset, black );
            image.setPixel( col, offset+1, white );
        }

    } else if( layout & TaskBarAttributes::Box ) {

        Q_ASSERT( width >= 2 && height >= 2 );
        int h_offset = (width - 2 )/2;
        int v_offset = (height - 2 )/2;

        image.setPixel( h_offset, v_offset, black );
        image.setPixel( h_offset, v_offset+1, black );
        image.setPixel( h_offset+1, v_offset, black );
        image.setPixel( h_offset+1, v_offset+1, white );

    }

    *this = fromImage( image );

}
