#ifndef _TaskBarConfiguration_h_
#define _TaskBarConfiguration_h_

// $Id: TaskBarConfiguration.h,v 1.17 2012/12/20 10:07:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "CustomDialog.h"
#include "TimeStamp.h"
#include "TaskBarAttributes.h"

#include <QtGui/QCheckBox>
#include <QtGui/QComboBox>
#include <QtGui/QSpinBox>
#include <QtGui/QWidget>
#include <QtCore/QHash>

class AnimatedLineEditor;
class CustomSlider;

//! task information editor dialog
class TaskBarConfiguration: public QWidget, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    TaskBarConfiguration(
    QWidget* parent,
    const TaskBarAttributes& attributes = TaskBarAttributes()
    );

    //! attributes
    void setAttributes( const TaskBarAttributes& attributes );

    //! retrieve backup attributes
    const TaskBarAttributes& backupAttributes( void )
    { return backupAttributes_; }

    //! retrieve attributes
    const TaskBarAttributes& attributes( void );

    signals:

    //! emmited when the pressed button is called
    void configurationChanged( const TaskBarAttributes& attributes );

    public slots:

    //! apply changes, emit config changed
    void apply( void )
    { emit configurationChanged( attributes() ); }

    //! reset
    void cancel( void )
    { emit configurationChanged( backupAttributes() ); }

    private slots:

    //! toggle button position
    void _togglePosition( QAbstractButton* );

    //! enable/disable columnSpinBox_ according to the layout
    void _updateLayout( const QString& value );

    //! enable/disable options according to the layout mode
    void _updateMode( const QString& value );

    //! update cheboxes depending on what is checked or not
    void _updateCheckBoxes( void );

    protected:

    //! create position box
    QWidget* _positionBox( QWidget *parent );

    //! check options
    void _check( void );

    private:

    //! map buttons to position
    typedef QHash< QAbstractButton*, TaskBarAttributes::PositionMode > ButtonMap;

    //! position buttons
    ButtonMap positionButtons_;

    //! attributes backup
    TaskBarAttributes backupAttributes_;

    //! associated TaskAttributes
    TaskBarAttributes attributes_;

    //! name editor
    AnimatedLineEditor* nameLineEdit_;

    //! layout combobox
    QComboBox* layoutComboBox_;

    //! mode combobox
    QComboBox* modeComboBox_;

    //! zoom delay spinbox
    QSpinBox* delaySpinBox_;

    //! n columns spinbox
    QSpinBox* columnSpinBox_;

    //! scale spinbox
    QSpinBox* scaleSpinBox_;

    //! checkboxes
    typedef QHash< TaskBarAttributes::Flag, QCheckBox* > CheckBoxMap;

    //! checkbox map
    CheckBoxMap checkboxes_;

};

#endif
