#ifndef TaskParser_h
#define TaskParser_h

// $Id: TaskParser.h,v 1.9 2012/12/20 10:07:16 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

#include "Counter.h"
#include "Debug.h"
#include "File.h"
#include "TaskBarAttributes.h"
#include "XmlError.h"

// forward declaration
class XmlDocument;

//! job parser based on Xml
class TaskParser: public Counter
{

    public:

    //! constructor
    TaskParser( void ):
        Counter( "TaskParser" )
    {}

    //! read from a file
    bool read( const File& file );

    //! write to file
    bool write( const File& file ) const;

    //! add attributes
    void addAttributes( const TaskBarAttributes& attributes )
    { attributesList_ << attributes; }

    //! get attributes
    const TaskBarAttributes::List& attributes( void )
    {
        if( !attributesList_.size() ) attributesList_ << TaskBarAttributes();
        return attributesList_;
    }

    //! Xml error
    const XmlError& xmlError( void ) const
    { return error_; }

    protected:

    //! read taskbar attributes
    bool _read( const XmlDocument&, TaskBarAttributes::List& ) const;

    private:

    //! xml error message, if any
    XmlError error_;

    //! list of all read TaskBarAttributes
    TaskBarAttributes::List attributesList_;

};

#endif
